<a id="mypy-boto3-emr"></a>

# mypy-boto3-emr

[![PyPI - mypy-boto3-emr](https://img.shields.io/pypi/v/mypy-boto3-emr.svg?color=blue)](https://pypi.org/project/mypy-boto3-emr)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-emr.svg?color=blue)](https://pypi.org/project/mypy-boto3-emr)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-emr?color=blue)](https://pypistats.org/packages/mypy-boto3-emr)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.EMR 1.17.104](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/emr.html#EMR)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.22.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-emr docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-emr](#mypy-boto3-emr)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `EMR` service.

```bash
python -m pip install boto3-stubs[emr]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[emr]` in your environment:
  `python -m pip install 'boto3-stubs[emr]'`

Both type checking and auto-complete should work for `EMR` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[emr]` in your environment:
  `python -m pip install 'boto3-stubs[emr]'`

Both type checking and auto-complete should work for `EMR` service. No explicit
type annotations required, write your `boto3` code as usual. Auto-complete can
be slow on big projects or if you have a lot of installed `boto3-stubs`
submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[emr]` in your environment:
  `python -m pip install 'boto3-stubs[emr]'`
- Run `mypy` as usual

Type checking should work for `EMR` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[emr]` in your environment:
  `python -m pip install 'boto3-stubs[emr]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `EMR` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`EMRClient` provides annotations for `boto3.client("emr")`.

```python
import boto3

from mypy_boto3_emr import EMRClient

client: EMRClient = boto3.client("emr")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: EMRClient = session.client("emr")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_emr.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_emr import EMRClient
from mypy_boto3_emr.paginator import (
    ListBootstrapActionsPaginator,
    ListClustersPaginator,
    ListInstanceFleetsPaginator,
    ListInstanceGroupsPaginator,
    ListInstancesPaginator,
    ListNotebookExecutionsPaginator,
    ListSecurityConfigurationsPaginator,
    ListStepsPaginator,
    ListStudioSessionMappingsPaginator,
    ListStudiosPaginator,
)

client: EMRClient = boto3.client("emr")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_bootstrap_actions_paginator: ListBootstrapActionsPaginator = client.get_paginator("list_bootstrap_actions")
list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
list_instance_fleets_paginator: ListInstanceFleetsPaginator = client.get_paginator("list_instance_fleets")
list_instance_groups_paginator: ListInstanceGroupsPaginator = client.get_paginator("list_instance_groups")
list_instances_paginator: ListInstancesPaginator = client.get_paginator("list_instances")
list_notebook_executions_paginator: ListNotebookExecutionsPaginator = client.get_paginator("list_notebook_executions")
list_security_configurations_paginator: ListSecurityConfigurationsPaginator = client.get_paginator("list_security_configurations")
list_steps_paginator: ListStepsPaginator = client.get_paginator("list_steps")
list_studio_session_mappings_paginator: ListStudioSessionMappingsPaginator = client.get_paginator("list_studio_session_mappings")
list_studios_paginator: ListStudiosPaginator = client.get_paginator("list_studios")
```

<a id="waiters-annotations"></a>

### Waiters annotations

`mypy_boto3_emr.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_emr import EMRClient
from mypy_boto3_emr.waiter import (
    ClusterRunningWaiter,
    ClusterTerminatedWaiter,
    StepCompleteWaiter,
)

client: EMRClient = boto3.client("emr")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
cluster_running_waiter: ClusterRunningWaiter = client.get_waiter("cluster_running")
cluster_terminated_waiter: ClusterTerminatedWaiter = client.get_waiter("cluster_terminated")
step_complete_waiter: StepCompleteWaiter = client.get_waiter("step_complete")
```

<a id="literals"></a>

### Literals

`mypy_boto3_emr.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_emr.literals import (
    ActionOnFailureType,
    AdjustmentTypeType,
    AuthModeType,
    AutoScalingPolicyStateChangeReasonCodeType,
    AutoScalingPolicyStateType,
    CancelStepsRequestStatusType,
    ClusterRunningWaiterName,
    ClusterStateChangeReasonCodeType,
    ClusterStateType,
    ClusterTerminatedWaiterName,
    ComparisonOperatorType,
    ComputeLimitsUnitTypeType,
    ExecutionEngineTypeType,
    IdentityTypeType,
    InstanceCollectionTypeType,
    InstanceFleetStateChangeReasonCodeType,
    InstanceFleetStateType,
    InstanceFleetTypeType,
    InstanceGroupStateChangeReasonCodeType,
    InstanceGroupStateType,
    InstanceGroupTypeType,
    InstanceRoleTypeType,
    InstanceStateChangeReasonCodeType,
    InstanceStateType,
    JobFlowExecutionStateType,
    ListBootstrapActionsPaginatorName,
    ListClustersPaginatorName,
    ListInstanceFleetsPaginatorName,
    ListInstanceGroupsPaginatorName,
    ListInstancesPaginatorName,
    ListNotebookExecutionsPaginatorName,
    ListSecurityConfigurationsPaginatorName,
    ListStepsPaginatorName,
    ListStudioSessionMappingsPaginatorName,
    ListStudiosPaginatorName,
    MarketTypeType,
    NotebookExecutionStatusType,
    OnDemandCapacityReservationPreferenceType,
    OnDemandCapacityReservationUsageStrategyType,
    OnDemandProvisioningAllocationStrategyType,
    PlacementGroupStrategyType,
    RepoUpgradeOnBootType,
    ScaleDownBehaviorType,
    SpotProvisioningAllocationStrategyType,
    SpotProvisioningTimeoutActionType,
    StatisticType,
    StepCancellationOptionType,
    StepCompleteWaiterName,
    StepExecutionStateType,
    StepStateChangeReasonCodeType,
    StepStateType,
    UnitType,
)

def check_value(value: ActionOnFailureType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_emr.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_emr.type_defs import (
    AddInstanceFleetInputRequestTypeDef,
    AddInstanceFleetOutputTypeDef,
    AddInstanceGroupsInputRequestTypeDef,
    AddInstanceGroupsOutputTypeDef,
    AddJobFlowStepsInputRequestTypeDef,
    AddJobFlowStepsOutputTypeDef,
    AddTagsInputRequestTypeDef,
    ApplicationTypeDef,
    AutoScalingPolicyDescriptionTypeDef,
    AutoScalingPolicyStateChangeReasonTypeDef,
    AutoScalingPolicyStatusTypeDef,
    AutoScalingPolicyTypeDef,
    BlockPublicAccessConfigurationMetadataTypeDef,
    BlockPublicAccessConfigurationTypeDef,
    BootstrapActionConfigTypeDef,
    BootstrapActionDetailTypeDef,
    CancelStepsInfoTypeDef,
    CancelStepsInputRequestTypeDef,
    CancelStepsOutputTypeDef,
    CloudWatchAlarmDefinitionTypeDef,
    ClusterStateChangeReasonTypeDef,
    ClusterStatusTypeDef,
    ClusterSummaryTypeDef,
    ClusterTimelineTypeDef,
    ClusterTypeDef,
    CommandTypeDef,
    ComputeLimitsTypeDef,
    ConfigurationTypeDef,
    CreateSecurityConfigurationInputRequestTypeDef,
    CreateSecurityConfigurationOutputTypeDef,
    CreateStudioInputRequestTypeDef,
    CreateStudioOutputTypeDef,
    CreateStudioSessionMappingInputRequestTypeDef,
    DeleteSecurityConfigurationInputRequestTypeDef,
    DeleteStudioInputRequestTypeDef,
    DeleteStudioSessionMappingInputRequestTypeDef,
    DescribeClusterInputRequestTypeDef,
    DescribeClusterOutputTypeDef,
    DescribeJobFlowsInputRequestTypeDef,
    DescribeJobFlowsOutputTypeDef,
    DescribeNotebookExecutionInputRequestTypeDef,
    DescribeNotebookExecutionOutputTypeDef,
    DescribeSecurityConfigurationInputRequestTypeDef,
    DescribeSecurityConfigurationOutputTypeDef,
    DescribeStepInputRequestTypeDef,
    DescribeStepOutputTypeDef,
    DescribeStudioInputRequestTypeDef,
    DescribeStudioOutputTypeDef,
    EbsBlockDeviceConfigTypeDef,
    EbsBlockDeviceTypeDef,
    EbsConfigurationTypeDef,
    EbsVolumeTypeDef,
    Ec2InstanceAttributesTypeDef,
    ExecutionEngineConfigTypeDef,
    FailureDetailsTypeDef,
    GetBlockPublicAccessConfigurationOutputTypeDef,
    GetManagedScalingPolicyInputRequestTypeDef,
    GetManagedScalingPolicyOutputTypeDef,
    GetStudioSessionMappingInputRequestTypeDef,
    GetStudioSessionMappingOutputTypeDef,
    HadoopJarStepConfigTypeDef,
    HadoopStepConfigTypeDef,
    InstanceFleetConfigTypeDef,
    InstanceFleetModifyConfigTypeDef,
    InstanceFleetProvisioningSpecificationsTypeDef,
    InstanceFleetStateChangeReasonTypeDef,
    InstanceFleetStatusTypeDef,
    InstanceFleetTimelineTypeDef,
    InstanceFleetTypeDef,
    InstanceGroupConfigTypeDef,
    InstanceGroupDetailTypeDef,
    InstanceGroupModifyConfigTypeDef,
    InstanceGroupStateChangeReasonTypeDef,
    InstanceGroupStatusTypeDef,
    InstanceGroupTimelineTypeDef,
    InstanceGroupTypeDef,
    InstanceResizePolicyTypeDef,
    InstanceStateChangeReasonTypeDef,
    InstanceStatusTypeDef,
    InstanceTimelineTypeDef,
    InstanceTypeConfigTypeDef,
    InstanceTypeDef,
    InstanceTypeSpecificationTypeDef,
    JobFlowDetailTypeDef,
    JobFlowExecutionStatusDetailTypeDef,
    JobFlowInstancesConfigTypeDef,
    JobFlowInstancesDetailTypeDef,
    KerberosAttributesTypeDef,
    KeyValueTypeDef,
    ListBootstrapActionsInputRequestTypeDef,
    ListBootstrapActionsOutputTypeDef,
    ListClustersInputRequestTypeDef,
    ListClustersOutputTypeDef,
    ListInstanceFleetsInputRequestTypeDef,
    ListInstanceFleetsOutputTypeDef,
    ListInstanceGroupsInputRequestTypeDef,
    ListInstanceGroupsOutputTypeDef,
    ListInstancesInputRequestTypeDef,
    ListInstancesOutputTypeDef,
    ListNotebookExecutionsInputRequestTypeDef,
    ListNotebookExecutionsOutputTypeDef,
    ListSecurityConfigurationsInputRequestTypeDef,
    ListSecurityConfigurationsOutputTypeDef,
    ListStepsInputRequestTypeDef,
    ListStepsOutputTypeDef,
    ListStudioSessionMappingsInputRequestTypeDef,
    ListStudioSessionMappingsOutputTypeDef,
    ListStudiosInputRequestTypeDef,
    ListStudiosOutputTypeDef,
    ManagedScalingPolicyTypeDef,
    MetricDimensionTypeDef,
    ModifyClusterInputRequestTypeDef,
    ModifyClusterOutputTypeDef,
    ModifyInstanceFleetInputRequestTypeDef,
    ModifyInstanceGroupsInputRequestTypeDef,
    NotebookExecutionSummaryTypeDef,
    NotebookExecutionTypeDef,
    OnDemandCapacityReservationOptionsTypeDef,
    OnDemandProvisioningSpecificationTypeDef,
    PaginatorConfigTypeDef,
    PlacementGroupConfigTypeDef,
    PlacementTypeTypeDef,
    PortRangeTypeDef,
    PutAutoScalingPolicyInputRequestTypeDef,
    PutAutoScalingPolicyOutputTypeDef,
    PutBlockPublicAccessConfigurationInputRequestTypeDef,
    PutManagedScalingPolicyInputRequestTypeDef,
    RemoveAutoScalingPolicyInputRequestTypeDef,
    RemoveManagedScalingPolicyInputRequestTypeDef,
    RemoveTagsInputRequestTypeDef,
    ResponseMetadataTypeDef,
    RunJobFlowInputRequestTypeDef,
    RunJobFlowOutputTypeDef,
    ScalingActionTypeDef,
    ScalingConstraintsTypeDef,
    ScalingRuleTypeDef,
    ScalingTriggerTypeDef,
    ScriptBootstrapActionConfigTypeDef,
    SecurityConfigurationSummaryTypeDef,
    SessionMappingDetailTypeDef,
    SessionMappingSummaryTypeDef,
    SetTerminationProtectionInputRequestTypeDef,
    SetVisibleToAllUsersInputRequestTypeDef,
    ShrinkPolicyTypeDef,
    SimpleScalingPolicyConfigurationTypeDef,
    SpotProvisioningSpecificationTypeDef,
    StartNotebookExecutionInputRequestTypeDef,
    StartNotebookExecutionOutputTypeDef,
    StepConfigTypeDef,
    StepDetailTypeDef,
    StepExecutionStatusDetailTypeDef,
    StepStateChangeReasonTypeDef,
    StepStatusTypeDef,
    StepSummaryTypeDef,
    StepTimelineTypeDef,
    StepTypeDef,
    StopNotebookExecutionInputRequestTypeDef,
    StudioSummaryTypeDef,
    StudioTypeDef,
    SupportedProductConfigTypeDef,
    TagTypeDef,
    TerminateJobFlowsInputRequestTypeDef,
    UpdateStudioInputRequestTypeDef,
    UpdateStudioSessionMappingInputRequestTypeDef,
    VolumeSpecificationTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AddInstanceFleetInputRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-emr` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-emr docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
